@@ -1,21 +1,26 @@
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 from textwrap import dedent
-import pytest
-from nbformat import from_dict
 
-from jupytext.compare import compare_notebooks
-from jupytext.formats import get_format_implementation, JupytextFormatError
+import pytest
+from nbformat.v4.nbbase import new_notebook
+from tornado.web import HTTPError
+
+import jupytext
+from jupytext.cli import jupytext as jupytext_cli
+from jupytext.formats import (
+    JupytextFormatError,
+    get_format_implementation,
+    guess_format,
+)
 from jupytext.myst import (
-    myst_to_notebook,
     CODE_DIRECTIVE,
     MystMetadataParsingError,
     matches_mystnb,
     myst_extensions,
+    myst_to_notebook,
 )
-from .utils import requires_myst
+
+from .utils import requires_myst, requires_no_myst
 
 
 @requires_myst
@@ -40,7 +45,7 @@ def test_bad_code_metadata():
         myst_to_notebook(
             dedent(
                 """\
-            ```{{{0}}}
+            ```{0}
             ---
             {{a
             ---
@@ -105,6 +110,17 @@ def test_matches_mystnb():
         """
     )
     assert matches_mystnb(text) is True
+    text = dedent(
+        """\
+        ---
+        a: 1
+        ---
+        > ```{code-cell}
+          ```
+        """
+    )
+    assert matches_mystnb(text) is True
+    assert guess_format(text, ".md") == ("myst", {})
 
 
 def test_not_installed():
@@ -114,8 +130,8 @@ def test_not_installed():
 
 
 @requires_myst
-def test_store_line_numbers():
-    notebook = matches_mystnb(
+def test_add_source_map():
+    notebook = myst_to_notebook(
         dedent(
             """\
             ---
@@ -124,7 +140,7 @@ def test_store_line_numbers():
             abc
             +++
             def
-            ```{{{0}}}
+            ```{0}
             ---
             b: 2
             ---
@@ -133,37 +149,47 @@ def test_store_line_numbers():
             xyz
             """
         ).format(CODE_DIRECTIVE),
-        store_line_numbers=True,
-        return_nb=True
+        add_source_map=True,
     )
-    expected = {
-        "nbformat": 4,
-        "nbformat_minor": 4,
-        "metadata": {"a": 1},
-        "cells": [
-            {
-                "cell_type": "markdown",
-                "source": "abc",
-                "metadata": {"_source_lines": [3, 4]},
-            },
-            {
-                "cell_type": "markdown",
-                "source": "def",
-                "metadata": {"_source_lines": [5, 6]},
-            },
-            {
-                "cell_type": "code",
-                "metadata": {"b": 2, "_source_lines": [7, 12]},
-                "execution_count": None,
-                "source": "c = 3",
-                "outputs": [],
-            },
-            {
-                "cell_type": "markdown",
-                "source": "xyz",
-                "metadata": {"_source_lines": [12, 13]},
-            },
-        ],
-    }
-    notebook.nbformat_minor = 4
-    compare_notebooks(notebook, from_dict(expected))
+    assert notebook.metadata.source_map == [3, 5, 7, 12]
+
+
+PLEASE_INSTALL_MYST = "The MyST Markdown format requires .*"
+
+
+@requires_no_myst
+def test_meaningfull_error_write_myst_missing(tmpdir):
+    nb_file = tmpdir.join("notebook.ipynb")
+    jupytext.write(new_notebook(), str(nb_file))
+
+    with pytest.raises(ImportError, match=PLEASE_INSTALL_MYST):
+        jupytext_cli([str(nb_file), "--to", "md:myst"])
+
+
+@requires_no_myst
+def test_meaningfull_error_open_myst_missing(tmpdir):
+    md_file = tmpdir.join("notebook.md")
+    md_file.write(
+        """---
+jupytext:
+  text_representation:
+    extension: '.md'
+    format_name: myst
+kernelspec:
+  display_name: Python 3
+  language: python
+  name: python3
+---
+
+1 + 1
+"""
+    )
+
+    with pytest.raises(ImportError, match=PLEASE_INSTALL_MYST):
+        jupytext_cli([str(md_file), "--to", "ipynb"])
+
+    cm = jupytext.TextFileContentsManager()
+    cm.root_dir = str(tmpdir)
+
+    with pytest.raises(HTTPError, match=PLEASE_INSTALL_MYST):
+        cm.get("notebook.md")
